@@ -6,8 +6,6 @@ from twilio.jwt.access_token import AccessToken
 from twilio.jwt.access_token.grants import ChatGrant, VideoGrant
 from twilio.rest import Client
 
-# from web import tx
-
 app = web.application(__name__, prefix="live")
 twilio_account_sid = app.cfg.get("TWILIO_ACCOUNT_SID")
 twilio_api_key_sid = app.cfg.get("TWILIO_API_KEY_SID")
@@ -34,7 +32,16 @@ class Live:
 
     def get(self):
         """"""
-        return app.view.live()
+        return app.view.index()
+
+
+@app.control("stream")
+class Stream:
+    """"""
+
+    def get(self):
+        """"""
+        return app.view.stream()
 
 
 @app.control("chat")
@@ -42,10 +49,10 @@ class Chat:
     """Chat with guests."""
 
     def get(self):
-        """Return the chat room."""
-        # if not tx.user.session:
+        """Return a chat room."""
+        # if not web.tx.user.session:
         #     raise web.SeeOther("/sign-in")
-        return app.view.room()
+        return app.view.chat()
 
     def post(self):
         """Sign user in to chat."""
